## Description

This folder contains some example notebooks for tables and plotting.
- I removed some excess code blocks and supplementary investigations.
- Does not comprehensively give code to all figures and tables.
- Many figures and tables would use the same basic code to summarize.
- Details in paper. 

Many analyses are automated via the pipeline in `workflow/simulate`
- These notebooks summarize the data after running the pipeline.

A table and a supplementary table related to true coalescent IBD is in `workflow/coalescent`

Analyses of sample size, detection threshold, frequency in based on `vignettes/required-sample-size.ipynb`.


